py5
---

py5 is a new version of Processing_ for Python 3.8+. It makes the Processing_ Java libraries available to the CPython interpreter using JPype_.

This entire repository is created by the meta-programming project py5generator_. Therefore, this code should not be edited manually. Any issues, etc, should be directed to the py5generator_ repository.

The `py5 documentation website 
<http://py5.ixora.io/>`_ provides basic tutorials and reference documentation.

.. _Processing: https://github.com/processing/processing4
.. _JPype: https://github.com/jpype-project/jpype
.. _py5generator: https://github.com/hx2A/py5generator
